@@ -60,7 +60,9 @@ __all__ = (
     "TableNotExistsWaiterName",
     "TableStatusType",
     "TimeToLiveStatusType",
+    "DynamoDBServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -148,6 +150,7 @@ TableStatusType = Literal[
     "UPDATING",
 ]
 TimeToLiveStatusType = Literal["DISABLED", "DISABLING", "ENABLED", "ENABLING"]
+DynamoDBServiceName = Literal["dynamodb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -179,6 +182,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -301,6 +305,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -449,5 +454,17 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_backups", "list_tables", "list_tags_of_resource", "query", "scan"]
 WaiterName = Literal["table_exists", "table_not_exists"]
