@@ -165,7 +165,7 @@ class Table(Boto3ServiceResource):
     table_class_summary: TableClassSummaryResponseMetadataTypeDef
     name: str
 
-    def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
+    def batch_writer(self, overwrite_by_pkeys: List[str] = ...) -> BatchWriter:
         """
         Create a batch writer object.
 
